@@ -113,7 +113,7 @@ class RDSClient():
         """
         """
         query = f"SELECT s3Bucket FROM neuralplatform_account a, neuralplatform_project p WHERE p.id = {project_id} AND p.account_id = a.id"
-        return self.select_query(query, fetchone=True).s3Bucket
+        return self.select_query(query, fetchone=True)['s3Bucket']
     
     def update_version_status(self,
                               version_id: int,
